@@ -40,6 +40,12 @@ class PartMan : public QObject
         Format, // Text: existing format (not QLineEdit text)
         Options
     };
+    enum TwitFlag {
+        OldLayout,
+        VirtualDevices,
+        AutoCrypto,
+        CryptoV
+    };
     MProcess &proc;
     BlockDeviceList &listBlkDevs;
     Ui::MeInstall &gui;
@@ -47,6 +53,7 @@ class PartMan : public QObject
     QMap<QString, QTreeWidgetItem *> mounts;
     QStringList listToUnmount;
     void setup();
+    void scanVirtualDevices(bool rescan);
     void clearLayout(QTreeWidgetItem *drvit);
     inline QTreeWidgetItem *addItem(QTreeWidgetItem *parent, int defaultMB,
         const QString &defaultUse, bool crypto);
@@ -61,10 +68,13 @@ class PartMan : public QObject
     void setEncryptChecks(const QString &use,
         enum Qt::CheckState state, QTreeWidgetItem *exclude);
     bool calculatePartBD();
+    QTreeWidgetItem *findOrigin(const QString &vdev);
     inline void drvitMarkLayout(QTreeWidgetItem *drvit, const bool old);
-    inline bool drvitIsMapperList(const QTreeWidgetItem *drvit) const;
+    inline bool twitFlag(const QTreeWidgetItem *twit, const TwitFlag flag) const;
+    inline void twitSetFlag(QTreeWidgetItem *twit, const TwitFlag flag, const bool value);
+    inline bool twitCanUse(QTreeWidgetItem *twit);
     inline bool twitIsOldLayout(const QTreeWidgetItem *twit, const bool chkUp=true) const;
-    inline long long twitSize(QTreeWidgetItem *twit, bool bytes=false);
+    inline long long twitSize(QTreeWidgetItem *twit, const bool bytes=false);
     inline bool twitWillFormat(QTreeWidgetItem *twit);
     inline QString twitUseFor(QTreeWidgetItem *twit);
     inline bool twitIsMapped(const QTreeWidgetItem *twit) const;
@@ -81,6 +91,8 @@ class PartMan : public QObject
     void partClearClick(bool);
     void partAddClick(bool);
     void partRemoveClick(bool);
+    void partMenuUnlock(QTreeWidgetItem *twit);
+    void partMenuLock(QTreeWidgetItem *twit);
     bool eventFilter(QObject *object, QEvent *event);
 public:
     bool gptoverride=false, uefi=false, brave=false;
